BusySetReg

Type Alias BusySetReg 

pub type BusySetReg = RegValueT<BusySetReg_SPEC>;
BSR Set Register

Aliased Type

pub struct BusySetReg { /* private fields */ }

Implementations

Source

impl BusySetReg

pub fn busy_spare( self, ) -> RegisterField<30, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_motor( self, ) -> RegisterField<28, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_timer2( self, ) -> RegisterField<26, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_timer( self, ) -> RegisterField<24, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_uart3( self, ) -> RegisterField<22, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_gpadc( self, ) -> RegisterField<20, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_pdm( self, ) -> RegisterField<18, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_src( self, ) -> RegisterField<16, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_pcm( self, ) -> RegisterField<14, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_sdadc( self, ) -> RegisterField<12, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_i2c2( self, ) -> RegisterField<10, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_i2c( self, ) -> RegisterField<8, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_spi2( self, ) -> RegisterField<6, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_spi( self, ) -> RegisterField<4, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_uart2( self, ) -> RegisterField<2, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.

pub fn busy_uart( self, ) -> RegisterField<0, 0x3, 1, 0, u8, u8, BusySetReg_SPEC, RW>

Writing a non-zero value to this field sets the corresponding BUSY bit, but only if it was not claimed (BUSY=0). Reading returns 0 to allow read/modify/write to the register.