Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 47 fields pub SAU: Sau, pub AES_HASH: AesHash, pub ANAMISC: Anamisc, pub APU: Apu, pub CACHE: Cache, pub CHARGER: Charger, pub CHIP_VERSION: ChipVersion, pub CMAC: Cmac, pub CMAC_TIMER_SLP: CmacTimerSlp, pub CRG_COM: CrgCom, pub CRG_PER: CrgPer, pub CRG_SYS: CrgSys, pub CRG_TOP: CrgTop, pub CRG_XTAL: CrgXtal, pub DCDC: Dcdc, pub DMA: Dma, pub DW: Dw, pub GPADC: Gpadc, pub GPIO: Gpio, pub GPREG: Gpreg, pub I2C: I2C, pub I2C2: I2C2, pub LCDC: Lcdc, pub LRA: Lra, pub MEMCTRL: Memctrl, pub OTPC: Otpc, pub PDC: Pdc, pub PWMLED: Pwmled, pub QSPIC: Qspic, pub QSPIC2: Qspic2, pub RFMON: Rfmon, pub RTC: Rtc, pub SDADC: Sdadc, pub SMOTOR: Smotor, pub SNC: Snc, pub SPI: Spi, pub SPI2: Spi2, pub SYS_WDOG: SysWdog, pub TIMER: Timer, pub TIMER2: Timer2, pub TIMER3: Timer3, pub TIMER4: Timer4, pub UART: Uart, pub UART2: Uart2, pub UART3: Uart3, pub USB: Usb, pub WAKEUP: Wakeup,
}
Required for compatibility with RTIC and other frameworks

Fields

SAU: SauAES_HASH: AesHashANAMISC: AnamiscAPU: ApuCACHE: CacheCHARGER: ChargerCHIP_VERSION: ChipVersionCMAC: CmacCMAC_TIMER_SLP: CmacTimerSlpCRG_COM: CrgComCRG_PER: CrgPerCRG_SYS: CrgSysCRG_TOP: CrgTopCRG_XTAL: CrgXtalDCDC: DcdcDMA: DmaDW: DwGPADC: GpadcGPIO: GpioGPREG: GpregI2C: I2CI2C2: I2C2LCDC: LcdcLRA: LraMEMCTRL: MemctrlOTPC: OtpcPDC: PdcPWMLED: PwmledQSPIC: QspicQSPIC2: Qspic2RFMON: RfmonRTC: RtcSDADC: SdadcSMOTOR: SmotorSNC: SncSPI: SpiSPI2: Spi2SYS_WDOG: SysWdogTIMER: TimerTIMER2: Timer2TIMER3: Timer3TIMER4: Timer4UART: UartUART2: Uart2UART3: Uart3USB: UsbWAKEUP: Wakeup

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks