pub struct Otpc { /* private fields */ }Implementations
Sourceimpl Otpc
impl Otpc
Sourcepub const fn otpc_mode_reg(&self) -> &'static Reg<OtpcModeReg_SPEC, RW>
pub const fn otpc_mode_reg(&self) -> &'static Reg<OtpcModeReg_SPEC, RW>
Mode register
Sourcepub const fn otpc_paddr_reg(&self) -> &'static Reg<OtpcPaddrReg_SPEC, RW>
pub const fn otpc_paddr_reg(&self) -> &'static Reg<OtpcPaddrReg_SPEC, RW>
The address of the word that will be programmed, when the PROG mode is used.
Sourcepub const fn otpc_pword_reg(&self) -> &'static Reg<OtpcPwordReg_SPEC, RW>
pub const fn otpc_pword_reg(&self) -> &'static Reg<OtpcPwordReg_SPEC, RW>
The 32-bit word that will be programmed, when the PROG mode is used.
Sourcepub const fn otpc_stat_reg(&self) -> &'static Reg<OtpcStatReg_SPEC, RW>
pub const fn otpc_stat_reg(&self) -> &'static Reg<OtpcStatReg_SPEC, RW>
Status register
Sourcepub const fn otpc_tim1_reg(&self) -> &'static Reg<OtpcTim1Reg_SPEC, RW>
pub const fn otpc_tim1_reg(&self) -> &'static Reg<OtpcTim1Reg_SPEC, RW>
Various timing parameters of the OTP cell.
Sourcepub const fn otpc_tim2_reg(&self) -> &'static Reg<OtpcTim2Reg_SPEC, RW>
pub const fn otpc_tim2_reg(&self) -> &'static Reg<OtpcTim2Reg_SPEC, RW>
Various timing parameters of the OTP cell.